@@ -436,7 +436,9 @@ void blowfish_ecb_decrypt(const unsigned char *ct, unsigned char *pt, symmetric_
 
 int blowfish_test(void)
 {
-#ifdef LTC_DOTESTS
+ #ifndef LTC_TEST
+    return CRYPT_NOP;
+ #else    
    int err;
    symmetric_key key;
    static const struct {
@@ -477,9 +479,7 @@ int blowfish_test(void)
       }
    }
    return CRYPT_OK;
-#else
-   return CRYPT_NOP;
-#endif /* LTC_DOTESTS */
+ #endif
 }
 
 int blowfish_keysize(int *desired_keysize)
